#ifndef CAMERADECODER_H
#define CAMERADECODER_H

#include <vector>
#include <thread>
#include "ara/log/logging.h"

class CameraDecoder
{
public:
	enum ErrorCode {
		Error_None,
		Error_Initialization,
		Error_IDR_Not_Received,
		Error_Allocation_Failed,
		Error_Start_Receive_Failed,
		Error_Send_Stream_Failed,
		Error_Get_Frame_Failed,
		Error_Decode_Failed,
	};

    CameraDecoder(int channel_number);
    ~CameraDecoder();
    ErrorCode decode(uint8_t* input_frame_buffer, size_t input_frame_size, bool is_IDR_frame, uint8_t *decoded_frame_data, size_t *decoded_data_size);

private:
    ara::log::Logger &log_{ara::log::CreateLogger("DECO", "camera decoder logger",
                                                    ara::log::LogLevel::kVerbose)};
    int      m_channel_number { 0 };
    bool     m_is_initialized { false };
    bool     m_first_IDR_received { false };
    uint8_t* m_outputAddr { nullptr };
    uint8_t* m_inputAddr { nullptr };

    static constexpr uint32_t m_width { 1920 };
    static constexpr uint32_t m_height { 1080 };
    static constexpr uint32_t m_output_size { m_width * m_height * 3 / 2 };

    bool initializeHiMpiSystem();
};

#endif // CAMERADECODER_H
